==> interactive-style-0.0.8.tgz: package/src/docs/index.js <==
import * as Components from '../index';

import React, { Fragment } from 'react';
import ReactDOM from 'react-dom';

import classnames from 'classnames';
import styles from './styles.scss';

import Page from 'Common/Page';
import CodeSnippet from 'Common/CodeSnippet';

class Docs extends React.Component {
  render() {
    return (
      <Page link='.' title='POLITICO Interactive Style'>
        <div className={classnames(styles.component)}>

          {/*
          <div className='navigation'>
            <a href='#quickshart'>Quickstart</a>
          </div> */}
          <Components.Head />
          <h2 id='quickstart'>Quickstart</h2>
          <br />
          <h4>Install</h4>
          <CodeSnippet
            value={`yarn add politico-style;`}
          />
          <h4>Import components...</h4>
          <CodeSnippet
            value={`import Components from 'politico-style';`}
          />
          <h4>Or Import components individually...</h4>
          <CodeSnippet
            value={`import { Headline } from 'politico-style';`}
          />
          <h4>Use the components to build an interactive page...</h4>
          <CodeSnippet
            value={`<Headline />Lorem ipsum dolor headline</Headline>`}
          />

          <h2 id='components'>Components</h2>
          <br />
          <h3 id='dynamic-advertisement'><a href='./Ad'>Dynamic Advertisement</a></h3>
          <p>{"Loads an Ad when mounted. Useful for situations where you don't have an explicit Ad ID (like in a loop)."}</p>
          <Components.Ad.Dynamic />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Dynamic />`}
          />
          <hr />

          <h3 id='static-advertisement'><a href='./Ad'>Static Advertisement</a></h3>
          <p>Loads an Ad with a given adID. If the component is ever re-rendered, you should use the dynamic Ad.</p>
          <Components.Ad.Static />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Static adID='pol-02' />`}
          />

          <h3 id='premade-advertisements'><a href='./Ad'>Premade Advertisements</a></h3>
          <p>Premade static ads with the appropriate adIDs already included.</p>
          <Components.Ad.Cube2 />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Banner />
<Ad.Cube1 />
<Ad.Cube2 />
<Ad.SuperCube1 />
<Ad.SuperCube2 />
<Ad.SuperCube3 />
<Ad.SuperCube4 />`}
          />
          <hr />

          <h3 id='comments'><a href='./Comments'>Comments</a></h3>
          <Components.Comments />
          <CodeSnippet
            value={`import { Comments } from '@politico/interactive-style';

<Comments />`}
          />
          <hr />

          <h3 id='container'><a href='./Container'>Container</a></h3>
          <p>Applies POLITICO Style theme styles to any elements inside.</p>
          <CodeSnippet
            value={`import { Container } from '@politico/interactive-style';

<Container>
  <p>This is some paragrah text inside a container.</p>
</Container>`}
          />
          <hr />

          <h3 id='dek'><a href='./Dek'>Dek</a></h3>
          <Components.Dek >Your Dek Here</Components.Dek>
          <CodeSnippet
            value={`import { Dek } from '@politico/interactive-style';

<Dek>
  Your Dek Here
</Dek>`}
          />
          <hr />

          <h3 id='head'><a href='./Head'>Head</a></h3>
          <p>Custom React Helmet setup with all the neccessary POLITICO style links, scripts, and meta tags.</p>
          <CodeSnippet
            value={`import { Head } from '@politico/interactive-style';

<Head
  title="My Page Title"
  publishPath="/interactives/my-publish-path/"
  social={socialInfo}
>
  <link rel="stylesheet" href="https://example.com/custom-head-element">
</Head>`}
          />
          <hr />

          <h3 id='headline'><a href='./Headline'>Headline</a></h3>
          <Components.Headline>Your Headline Here</Components.Headline>
          <CodeSnippet
            value={`import { Headline } from '@politico/interactive-style';

<Headline>
  Your Headline Here
</Headline>`}
          />
          <hr />

          <h3 id='info'><a href='./Info'>Info</a></h3>
          <p>Contains information about authors, publish dates, and updated dates. Handles formatting for dates and multiple authors.</p>
          <Components.Info
            authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
            published={new Date().toISOString()}
          />
          <CodeSnippet
            value={`import { Info } from '@politico/interactive-style';

<Info
  authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
  published={new Date().toISOString()}

  updated={updated}
/>`}
          />
          <hr />

          <h3 id='navigation'><a href='./Navigation'>Navigation</a></h3>
          <Components.Navigation />
          <CodeSnippet
            value={`import { Navigation } from '@politico/interactive-style';

< /Navigation>`}
          />
          <hr />

          <h3 id='section'><a href='./Section'>Section</a></h3>
          <Components.Section href='https://www.politico.com/white-house'>White House</Components.Section>
          <CodeSnippet
            value={`import { Section } from '@politico/interactive-style';
<Section href='https://www.politico.com/white-house'>
  White House
<Section>`}
          />
          <hr />

          <h3 id='share'><a href='./Share'>Share</a></h3>
          <Components.Share
            subject='My Subject Line'
            shareTweet='My Share Tweet'
          />
          <CodeSnippet
            value={`import { Share } from '@politico/interactive-style';

<Share
  subject='My Subject Line'
  shareTweet='My Share Tweet'
/>
`}
          />
          <hr />

          <h2 id='example'>Putting it all together</h2>
          <div className='example'>
            <Components.Navigation />
            <Components.Ad.Banner />
            <Components.Share
              subject='My Subject Line'
              shareTweet='My Share Tweet'
            />
            <Components.Section href='https://www.politico.com/white-house'>White House</Components.Section>
            <Components.Headline>Your Headline Here</Components.Headline>
            <Components.Dek >Your Dek Here</Components.Dek>
            <Components.Info
              authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
              published={new Date().toISOString()}
            />
            <Components.Container>
              <p>
              Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
              </p>
              <Components.Ad.Dynamic />
              <p>
              Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
              </p>
            </Components.Container>
            <Components.Comments />
          </div>
          <br />
          <CodeSnippet
            value={`import { Ad, Comments, Container, Dek, Head, Headline, Info, Navigation, Section, Share } from '@politico/interactive-style';

<Head />

<Navigation />

<Ad.Banner />

<Share
  subject='My Subject Line'
  shareTweet='My Share Tweet'
/>

<Section href='https://www.politico.com/white-house'>White House</Section>

<Headline>Your Headline Here</Headline>

<Dek >Your Dek Here</Dek>

<Info
  authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
  published={new Date().toISOString()}
/>

<Container>
  <p>
    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
  </p>

  <Ad.Dynamic />

  <p>
    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
  </p>
</Container>

<Comments />
`} />
        </div>
      </Page>
    );
  }
}

window.pibOptions = {
  'siteSection': 'politics',
  'pageType': 'interactives',
  'adUnitSection': 'politics',
  'freePaidContent': 'free',
};

ReactDOM.render(<Docs />, document.getElementById('app'));

==> interactive-style-0.0.11.tgz: package/src/docs/index.js <==
import * as Components from '../index';

import React, { Fragment } from 'react';
import ReactDOM from 'react-dom';

import classnames from 'classnames';
import styles from './styles.scss';

import Page from 'Common/Page';
import CodeSnippet from 'Common/CodeSnippet';

class Docs extends React.Component {
  render() {
    return (
      <Page link='.' title='POLITICO Interactive Style'>
        <div className={classnames(styles.component)}>

          {/*
          <div className='navigation'>
            <a href='#quickshart'>Quickstart</a>
          </div> */}
          <Components.Head />
          <h2 id='quickstart'>Quickstart</h2>
          <br />
          <h4>Install</h4>
          <CodeSnippet
            value={`yarn add @politico/interactive-style;`}
          />
          <h4>Import components...</h4>
          <CodeSnippet
            value={`import Components from '@politico/interactive-style';`}
          />
          <h4>Or Import components individually...</h4>
          <CodeSnippet
            value={`import { Headline } from '@politico/interactive-style';`}
          />
          <h4>Use the components to build an interactive page...</h4>
          <CodeSnippet
            value={`<Headline/>Lorem ipsum dolor headline</Headline>`}
          />
          <hr />
          <h2 id='components'>Components</h2>
          <br />
          <h3 id='dynamic-advertisement'><a href='./Ad'>Dynamic Advertisement</a></h3>
          <p>{"Loads an Ad when mounted. Useful for situations where you don't have an explicit Ad ID (like in a loop)."}</p>
          <Components.Ad.Dynamic />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Dynamic />`}
          />
          <hr />

          <h3 id='static-advertisement'><a href='./Ad'>Static Advertisement</a></h3>
          <p>Loads an Ad with a given adID. If the component is ever re-rendered, you should use the dynamic Ad.</p>
          <Components.Ad.Static />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Static adID='pol-02' />`}
          />

          <h3 id='premade-advertisements'><a href='./Ad'>Premade Advertisements</a></h3>
          <p>Premade static ads with the appropriate adIDs already included.</p>
          <Components.Ad.Cube2 />
          <CodeSnippet
            value={`import { Ad } from '@politico/interactive-style';

<Ad.Banner />
<Ad.Cube1 />
<Ad.Cube2 />
<Ad.SuperCube1 />
<Ad.SuperCube2 />
<Ad.SuperCube3 />
<Ad.SuperCube4 />`}
          />
          <hr />

          <h3 id='comments'><a href='./Comments'>Comments</a></h3>
          <Components.Comments publishPath='/interactives/example-page/' />
          <CodeSnippet
            value={`import { Comments } from '@politico/interactive-style';

<Comments publishPath='/interactives/example-page/' />`}
          />
          <hr />

          <h3 id='container'><a href='./Container'>Container</a></h3>
          <p>Applies POLITICO Style theme styles to any elements inside.</p>
          <CodeSnippet
            value={`import { Container } from '@politico/interactive-style';

<Container>
  <p>This is some paragrah text inside a container.</p>
</Container>`}
          />
          <hr />

          <h3 id='dek'><a href='./Dek'>Dek</a></h3>
          <Components.Dek >Your Dek Here</Components.Dek>
          <CodeSnippet
            value={`import { Dek } from '@politico/interactive-style';

<Dek>
  Your Dek Here
</Dek>`}
          />
          <hr />

          <h3 id='head'><a href='./Head'>Head</a></h3>
          <p>Custom React Helmet setup with all the neccessary POLITICO style links, scripts, and meta tags.</p>
          <CodeSnippet
            value={`import { Head } from '@politico/interactive-style';

<Head
  title="My Page Title"
  publishPath="/interactives/my-publish-path/"
  social={socialInfo}
>
  <link rel="stylesheet" href="https://example.com/custom-head-element">
</Head>`}
          />
          <hr />

          <h3 id='headline'><a href='./Headline'>Headline</a></h3>
          <Components.Headline>Your Headline Here</Components.Headline>
          <CodeSnippet
            value={`import { Headline } from '@politico/interactive-style';

<Headline>
  Your Headline Here
</Headline>`}
          />
          <hr />

          <h3 id='info'><a href='./Info'>Info</a></h3>
          <p>Contains information about authors, publish dates, and updated dates. Handles formatting for dates and multiple authors.</p>
          <Components.Info
            authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
            published={new Date().toISOString()}
          />
          <CodeSnippet
            value={`import { Info } from '@politico/interactive-style';

<Info
  authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
  published={new Date().toISOString()}

  updated={updated}
/>`}
          />
          <hr />

          <h3 id='navigation'><a href='./Navigation'>Navigation</a></h3>
          <Components.Navigation />
          <CodeSnippet
            value={`import { Navigation } from '@politico/interactive-style';

<Navigation />`}
          />
          <hr />

          <h3 id='section'><a href='./Section'>Section</a></h3>
          <Components.Section href='https://www.politico.com/white-house'>White House</Components.Section>
          <CodeSnippet
            value={`import { Section } from '@politico/interactive-style';
<Section href='https://www.politico.com/white-house'>
  White House
<Section>`}
          />
          <hr />

          <h3 id='share'><a href='./Share'>Share</a></h3>
          <Components.Share
            subject='My Subject Line'
            shareTweet='My Share Tweet'
          />
          <CodeSnippet
            value={`import { Share } from '@politico/interactive-style';

<Share
  subject='My Subject Line'
  shareTweet='My Share Tweet'
/>
`}
          />
          <hr />

          <h2 id='example'>Putting it all together</h2>
          <div className='example'>
            <Components.Navigation />
            <Components.Ad.Banner />
            <Components.Share
              subject='My Subject Line'
              shareTweet='My Share Tweet'
            />
            <Components.Section href='https://www.politico.com/white-house'>White House</Components.Section>
            <Components.Headline>Your Headline Here</Components.Headline>
            <Components.Dek >Your Dek Here</Components.Dek>
            <Components.Info
              authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
              published={new Date().toISOString()}
            />
            <Components.Container>
              <p>
              Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
              </p>
              <Components.Ad.Dynamic />
              <p>
              Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
              </p>
            </Components.Container>
            <Components.Comments publishPath='/interactives/example-page/' />
          </div>
          <br />
          <CodeSnippet
            value={`import { Ad, Comments, Container, Dek, Head, Headline, Info, Navigation, Section, Share } from '@politico/interactive-style';

<Head tilte='My Page' publishPath='/interactives/example-page/' social={ {...} } />

<Navigation />

<Ad.Banner />

<Share
  subject='My Subject Line'
  shareTweet='My Share Tweet'
/>

<Section href='https://www.politico.com/white-house'>White House</Section>

<Headline>Your Headline Here</Headline>

<Dek>Your Dek Here</Dek>

<Info
  authors={[{ link: 'https://politico.com', name: 'Polly Politico' }]}
  published={new Date().toISOString()}
/>

<Container>
  <p>
    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
  </p>

  <Ad.Dynamic />

  <p>
    Lorem ipsum dolor sit amet, consectetur adipisicing elit, sed do eiusmod tempor incididunt ut labore et dolore magna aliqua. Ut enim ad minim veniam, quis nostrud exercitation ullamco laboris nisi ut aliquip ex ea commodo consequat.
  </p>
</Container>

<Comments publishPath='/interactives/example-page/' />
`} />
        </div>
      </Page>
    );
  }
}

window.pibOptions = {
  'siteSection': 'politics',
  'pageType': 'interactives',
  'adUnitSection': 'politics',
  'freePaidContent': 'free',
};

ReactDOM.render(<Docs />, document.getElementById('app'));
